#
# spec file for package python-pytest-qt
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pytest-qt
Version:        3.3.0
Release:        bp155.2.15
Summary:        Pytest support for PyQt and PySide applications
License:        MIT
Group:          Development/Languages/Python
URL:            http://github.com/pytest-dev/pytest-qt
Source:         https://files.pythonhosted.org/packages/source/p/pytest-qt/pytest-qt-%{version}.tar.gz
Patch0:         skip-timeout-tests.patch
BuildRequires:  %{python_module pytest >= 3.0}
BuildRequires:  %{python_module qt5}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  xvfb-run
Requires:       python-pytest >= 3.0
Requires:       python-qt5
BuildArch:      noarch
%python_subpackages

%description
Pytest-qt is a pytest plugin that allows programmers to write tests
for PySide and PyQt applications.

The main usage is to use the `qtbot` fixture, responsible for handling `qApp`
creation as needed and provides methods to simulate user interaction,
like key presses and mouse clicks.

%prep
%setup -q -n pytest-qt-%{version}
%patch0 -p1
dos2unix LICENSE

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTEST_QT_API=pyqt5
export PYTHONDONTWRITEBYTECODE=1
# skip test_qt_api_ini_config_with_envvar as it needs the qt4 and pyside/etc
# same applies for test_qt_api_ini_config
%{python_expand export PYTHONPATH="%{buildroot}%{$python_sitelib}"
xvfb-run --server-args="-screen 0 1920x1080x24" py.test-%{$python_bin_suffix} -k 'not test_qt_api_ini_config_with_envvar and not test_qt_api_ini_config'
}

%files %{python_files}
%license LICENSE
%doc CHANGELOG.rst README.rst
%{python_sitelib}/*

%changelog
* Mon Jan  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.3.0:
  * Improve message in uncaught exceptions by mentioning the Qt event loop instead of Qt virtual methods (#255).
  * pytest-qt now requires pytest version >= 3.0.
  * qtbot.addWiget now supports an optional before_close_func keyword-only argument, which if given is a function which is called before the widget is closed, with the widget as first argument.
* Thu Jan 31 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.2:
  * Fix Off-by-one error in modeltester (#249). Thanks @ext-jmmugnes for the PR.
* Fri Dec  7 2018 Todd R <toddrme2178@gmail.com>
- Update to version 3.2.1
  * Fixed compatibility with PyQt5 5.11.3
- Update to version 3.2.0
  * The ``CallbackBlocker`` returned by ``qtbot.waitCallback()`` now has a new
    ``assert_called_with(...)`` convenience method.
- Update to version 3.1.0
  * If Qt's model tester implemented in C++ is available (PyQt5 5.11 or newer),
    the ``qtmodeltester`` fixture now uses that instead of the Python
    implementation. This can be turned off by passing  ``force_py=True`` to
    ``qtmodeltester.check()``.
  * The Python code used by ``qtmodeltester`` is now based on the latest Qt
    modeltester. This also means that the ``data_display_may_return_none``
    attribute for ``qtmodeltester`` isn't used anymore.
  * New ``qtbot.waitCallback()`` method that returns a ``CallbackBlocker``, which
    can be used to wait for a callback to be called.
  * ``qtbot.assertNotEmitted`` now has a new ``wait`` parameter which can be used
    to make sure asynchronous signals aren't emitted by waiting after the code in
    the ``with`` block finished.
  * The ``qt_wait_signal_raising`` option was renamed to ``qt_default_raising``.
    The old name continues to work, but is deprecated.
  * The docs still referred to ``SignalTimeoutError`` in some places, despite it
    being renamed to ``TimeoutError`` in the 2.1 release. This is now corrected.
  * Improve debugging output when no Qt wrapper was found.
  * When no context is available for warnings on Qt 5, no ``None:None:0`` line is
    shown anymore.
  * The ``no_qt_log`` marker is now registered with pytest so ``--strict`` can be
    used.
  * ``qtbot.waitSignal`` with timeout ``0`` now expects the signal to arrive
    directly in the code enclosed by it.
- Update to version 3.0.2
  * Another fix related to ``QtInfoMsg`` objects during logging (`#225`_).
- Update to version 3.0.1
  * Fix handling of ``QtInfoMsg`` objects during logging (`#225`_).
    Thanks `@willsALMANJ`_ for the report.
- Update to version 3.0.0
  * Removed ``qtbot.mouseEvent`` proxy, it was an internal Qt function which has
    now been removed in PyQt 5.11 (`#219`_). Thanks `@mitya57`_ for the PR.
  * Fix memory leak when tests raised an exception inside Qt virtual methods (`#187`_).
    Thanks `@fabioz`_ for the report and PR.
- Rebase skip-timeout-tests.patch
* Thu May 31 2018 toddrme2178@gmail.com
- Update to 2.3.2
  * Use new pytest 3.6 marker API when possible.
* Sun May 13 2018 tchvatal@suse.com
- Enable tests
- Add patch skip-timeout-tests.patch to skip test randomly
  failing in OBS
* Sat May 12 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2.3.1:
  * PYTEST_QT_API environment variable correctly wins over qt_api ini
    variable if both are set at the same time (#196). Thanks @mochick
    for the PR.
- changes from version 2.3.0:
  * New qapp_args fixture which can be used to pass custom arguments
    to QApplication. Thanks @The-Compiler for the PR.
- changes from version 2.2.1:
  * modeltester now accepts QBrush for BackgroundColorRole and
    TextColorRole (#189). Thanks @p0las for the PR.
- changes from version 2.2.0:
  * pytest-qt now supports PySide2 thanks to @rth!
* Mon Aug 28 2017 toddrme2178@gmail.com
- Initial version
